import LogicFlow, { EdgeConfig, GraphConfigData, Point } from "@logicflow/core";
import "@logicflow/core/dist/style/index.css";
import { Control } from "@logicflow/extension";
import "@logicflow/extension/lib/style/index.css";
import { useEffect, useRef } from "react";

export interface IRendererProps {
  chartData: GraphConfigData;
  setPointsList: (newPointsList: Point[]) => void;
}

const Renderer = (props: IRendererProps) => {
  const containerRef = useRef<HTMLDivElement>(null);
  const lfRef = useRef<LogicFlow>();

  const { chartData, setPointsList } = props;

  useEffect(() => {
    LogicFlow.use(Control);
    lfRef.current = new LogicFlow({
      container: containerRef.current!,
      width: 800,
      height: 300,
    });
    lfRef.current.render(chartData);

    lfRef.current.on("edge:adjust", handleEdgeAdjust);
  }, []);

  const handleEdgeAdjust = (res: { data: EdgeConfig }) => {
    console.log(res.data);
    setPointsList(res.data.pointsList as Point[]);
  };

  return (
    <div style={{ border: "2px solid #ccc", width: "fit-content" }}>
      <div ref={containerRef} />
    </div>
  );
};

export default Renderer;
